import { IDisposable } from 'monaco-editor/esm/vs/editor/editor.api.js';
export interface MonacoUnifiedOptions {
    /**
     * The label to use for the worker.
     *
     * This is used to match a worker in in `MonacoEnvironment`.
     */
    label: string;
    /**
     * The language ID or IDs to which to apply `monaco-unified`.
     */
    languageSelector: string[] | string;
    /**
     * The configuration that will be sent to the worker.
     */
    configuration?: unknown;
    /**
     * By default `monaco-unified` supports formatting using unified. Set this to `false` to disable.
     *
     * @default true
     */
    formatting?: boolean;
    /**
     * By default `monaco-unified` supports validation using unified. Set this to `false` to disable.
     *
     * @default true
     */
    validation?: boolean;
}
export interface MonacoUnified extends IDisposable {
    /**
     * Update the configuration.
     */
    reconfigure: (configuration: unknown) => void;
}
/**
 * Configure monaco-unified.
 *
 * @param monaco - The `monaco-editor` module to use.
 * @param options - Options to configure `monaco-unified`.
 * @returns A disposable
 */
export declare function configureMonacoUnified(monaco: typeof import('monaco-editor'), options: MonacoUnifiedOptions): MonacoUnified;
